# ConstsTaskType


## Enum

* `EMPTY` (value: `''`)

* `RESTARTSERVICE` (value: `'RestartService'`)

* `RUNALGORITHM` (value: `'RunAlgorithm'`)

* `FAULTINJECTION` (value: `'FaultInjection'`)

* `BUILDIMAGES` (value: `'BuildImages'`)

* `BUILDDATASET` (value: `'BuildDataset'`)

* `COLLECTRESULT` (value: `'CollectResult'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


